@@ -49,99 +49,6 @@ class TestNicConfigs(base.TestCase):
         self.assertEqual("The 'config' property of 'foo' must be"
                          " a dictionary.", errors[0])
 
-    def test_get_network_config(self):
-        # Test config lookup using current format (t-h-t >= Ocata)
-        resources = {
-            'properties': {
-                'config': {
-                    'str_replace': {
-                        'params': {
-                            '$network_config': {
-                                'network_config': [
-                                    'current'
-                                ]
-                            }
-                        }
-                    }
-                }
-            }
-        }
-        self.assertEqual(
-            validation.get_network_config(resources, 'foo')[0],
-            'current')
-
-    def test_get_network_config_returns_none_if_not_found(self):
-        # get_network_config should return None if
-        # any of the keys cannot be found in the resources tree:
-        # `properties`, `config`, `network_config`
-        no_properties = {
-            'bar': {
-                'config': {
-                    'str_replace': {
-                        'params': {
-                            '$network_config': {
-                                'network_config': [
-                                    'current'
-                                ]
-                            }
-                        }
-                    }
-                }
-            }
-        }
-        no_config = {
-            'properties': {
-                'bar': {
-                    'str_replace': {
-                        'params': {
-                            '$network_config': {
-                                'network_config': [
-                                    'current'
-                                ]
-                            }
-                        }
-                    }
-                }
-            }
-        }
-        no_network_config = {
-            'properties': {
-                'config': {
-                    'str_replace': {
-                        'params': {
-                            '$network_config': {
-                                'bar': {
-                                    'some': 'val'
-                                }
-                            }
-                        }
-                    }
-                }
-            }
-        }
-        self.assertEqual(
-            validation.get_network_config(no_properties, 'foo'), None)
-        self.assertEqual(validation.get_network_config(no_config, 'foo'), None)
-        self.assertEqual(
-            validation.get_network_config(no_network_config, 'foo'), None)
-
-    def test_get_network_config_old_format(self):
-        # Test config lookup using format used in t-h-t <= Newton
-        resources = {
-            'properties': {
-                'config': {
-                    'os_net_config': {
-                        'network_config': [
-                            'old'
-                        ]
-                    }
-                }
-            }
-        }
-        self.assertEqual(
-            validation.get_network_config(resources, 'foo')[0],
-            'old')
-
     def nic_data(self, bridges):
         return {
             'resources': {
@@ -167,6 +74,8 @@ class TestNicConfigs(base.TestCase):
         self.assertEqual(len(errors), 1)
         self.assertIn("'foo' must be a list", errors[0])
 
+    # See comment from 2018-11-22 in library/network_environment.py
+    """
     def test_bridge_has_type(self):
         nic_data = self.nic_data([{
             'name': 'storage',
@@ -236,6 +145,7 @@ class TestNicConfigs(base.TestCase):
         self.assertEqual(len(errors), 1)
         self.assertIn("members/items/oneOf: {} is not valid under any"
                       " of the given schemas", errors[0])
+    """
 
     def test_more_than_one_bond(self):
         nic_data = self.nic_data([{
@@ -289,6 +199,8 @@ class TestNicConfigs(base.TestCase):
         errors = validation.check_nic_configs("controller.yaml", nic_data)
         self.assertEqual([], errors)
 
+    # See comment from 2018-11-22 in library/network_environment.py
+    """
     def test_one_bond_no_interfaces(self):
         nic_data = self.nic_data([{
             'type': 'ovs_bridge',
@@ -300,6 +212,7 @@ class TestNicConfigs(base.TestCase):
         errors = validation.check_nic_configs("controller.yaml", nic_data)
         self.assertEqual(len(errors), 1)
         self.assertIn('members/minItems: [] is too short', errors[0])
+    """
 
     def test_one_bond_multiple_interfaces(self):
         nic_data = self.nic_data([{
