@@ -16,7 +16,7 @@
 
 import re
 
-from ansible.module_utils.basic import *  # NOQA
+from ansible.module_utils.basic import AnsibleModule
 
 DOCUMENTATION = '''
 ---
